"""Control Operating Systems."""

from __future__ import annotations

from abc import ABC, abstractmethod
from os import sep
from pathlib import Path

from .debian import Debian


class OS(ABC):
    """Operating System."""

    def __init__(self, path: Path) -> None:
        """Set root."""
        self.root = path
        self.name = self.get_name()

    @abstractmethod
    def get_name(self) -> str:
        """Return mandatory name."""

    @staticmethod
    def from_path(path: Path) -> OS:
        """Initialize from an already existing path."""
        return Debian(path)


os = OS.from_path(Path(sep))
